@@ -16,7 +16,6 @@
 # under the License.
 from __future__ import annotations
 
-import argparse
 from collections import defaultdict
 from collections.abc import Sequence
 from functools import cached_property
@@ -27,19 +26,15 @@ from fastapi import FastAPI
 
 from airflow.api_fastapi.app import AUTH_MANAGER_FASTAPI_APP_PREFIX
 from airflow.api_fastapi.auth.managers.base_auth_manager import BaseAuthManager
-from airflow.cli.cli_config import CLICommand, DefaultHelpParser, GroupCommand
-from airflow.configuration import conf
-from airflow.exceptions import AirflowOptionalProviderFeatureException
+from airflow.cli.cli_config import CLICommand
 from airflow.providers.amazon.aws.auth_manager.avp.entities import AvpEntities
 from airflow.providers.amazon.aws.auth_manager.avp.facade import (
     AwsAuthManagerAmazonVerifiedPermissionsFacade,
     IsAuthorizedRequest,
 )
-from airflow.providers.amazon.aws.auth_manager.cli.definition import (
-    AWS_AUTH_MANAGER_COMMANDS,
-)
 from airflow.providers.amazon.aws.auth_manager.user import AwsAuthManagerUser
 from airflow.providers.amazon.version_compat import AIRFLOW_V_3_0_PLUS
+from airflow.providers.common.compat.sdk import AirflowOptionalProviderFeatureException, conf
 
 if TYPE_CHECKING:
     from airflow.api_fastapi.auth.managers.base_auth_manager import ResourceMethod
@@ -62,6 +57,7 @@ if TYPE_CHECKING:
         VariableDetails,
     )
     from airflow.api_fastapi.common.types import MenuItem
+    from airflow.cli.cli_config import CLICommand
 
 
 class AwsAuthManager(BaseAuthManager[AwsAuthManagerUser]):
@@ -468,13 +464,9 @@ class AwsAuthManager(BaseAuthManager[AwsAuthManagerUser]):
     @staticmethod
     def get_cli_commands() -> list[CLICommand]:
         """Vends CLI commands to be included in Airflow CLI."""
-        return [
-            GroupCommand(
-                name="aws-auth-manager",
-                help="Manage resources used by AWS auth manager",
-                subcommands=AWS_AUTH_MANAGER_COMMANDS,
-            ),
-        ]
+        from airflow.providers.amazon.aws.cli.definition import get_aws_cli_commands
+
+        return get_aws_cli_commands()
 
     def get_fastapi_app(self) -> FastAPI | None:
         from airflow.providers.amazon.aws.auth_manager.routes.login import login_router
@@ -515,14 +507,3 @@ class AwsAuthManager(BaseAuthManager[AwsAuthManagerUser]):
                 "Please update it to its latest version. "
                 "See doc: https://airflow.apache.org/docs/apache-airflow-providers-amazon/stable/auth-manager/setup/amazon-verified-permissions.html#update-the-policy-store-schema."
             )
-
-
-def get_parser() -> argparse.ArgumentParser:
-    """Generate documentation; used by Sphinx argparse."""
-    from airflow.cli.cli_parser import AirflowHelpFormatter, _add_command
-
-    parser = DefaultHelpParser(prog="airflow", formatter_class=AirflowHelpFormatter)
-    subparsers = parser.add_subparsers(dest="subcommand", metavar="GROUP_OR_COMMAND")
-    for group_command in AwsAuthManager.get_cli_commands():
-        _add_command(subparsers, group_command)
-    return parser
