@@ -18,21 +18,22 @@
 from __future__ import annotations
 
 from collections.abc import Sequence
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
-from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.ec2 import EC2Hook
 from airflow.providers.amazon.aws.links.ec2 import (
     EC2InstanceDashboardLink,
     EC2InstanceLink,
 )
+from airflow.providers.amazon.aws.operators.base_aws import AwsBaseOperator
+from airflow.providers.amazon.aws.utils.mixins import aws_template_fields
+from airflow.providers.common.compat.sdk import AirflowException
 
 if TYPE_CHECKING:
-    from airflow.utils.context import Context
+    from airflow.sdk import Context
 
 
-class EC2StartInstanceOperator(BaseOperator):
+class EC2StartInstanceOperator(AwsBaseOperator[EC2Hook]):
     """
     Start AWS EC2 instance using boto3.
 
@@ -41,18 +42,21 @@ class EC2StartInstanceOperator(BaseOperator):
         :ref:`howto/operator:EC2StartInstanceOperator`
 
     :param instance_id: id of the AWS EC2 instance
-    :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default boto3 behaviour is used. If
+        :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :param region_name: (optional) aws region name associated with the client
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
     :param check_interval: time in seconds that the job should wait in
         between each instance state checks until operation is completed
     """
 
+    aws_hook_class = EC2Hook
     operator_extra_links = (EC2InstanceLink(),)
-    template_fields: Sequence[str] = ("instance_id", "region_name")
+    template_fields: Sequence[str] = aws_template_fields("instance_id", "region_name")
     ui_color = "#eeaa11"
     ui_fgcolor = "#ffffff"
 
@@ -60,37 +64,32 @@ class EC2StartInstanceOperator(BaseOperator):
         self,
         *,
         instance_id: str,
-        aws_conn_id: str | None = "aws_default",
-        region_name: str | None = None,
         check_interval: float = 15,
         **kwargs,
     ):
         super().__init__(**kwargs)
         self.instance_id = instance_id
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.check_interval = check_interval
 
     def execute(self, context: Context):
-        ec2_hook = EC2Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
         self.log.info("Starting EC2 instance %s", self.instance_id)
-        instance = ec2_hook.get_instance(instance_id=self.instance_id)
+        instance = self.hook.get_instance(instance_id=self.instance_id)
         instance.start()
         EC2InstanceLink.persist(
             context=context,
             operator=self,
-            aws_partition=ec2_hook.conn_partition,
+            aws_partition=self.hook.conn_partition,
             instance_id=self.instance_id,
-            region_name=ec2_hook.conn_region_name,
+            region_name=self.hook.conn_region_name,
         )
-        ec2_hook.wait_for_state(
+        self.hook.wait_for_state(
             instance_id=self.instance_id,
             target_state="running",
             check_interval=self.check_interval,
         )
 
 
-class EC2StopInstanceOperator(BaseOperator):
+class EC2StopInstanceOperator(AwsBaseOperator[EC2Hook]):
     """
     Stop AWS EC2 instance using boto3.
 
@@ -100,17 +99,20 @@ class EC2StopInstanceOperator(BaseOperator):
 
     :param instance_id: id of the AWS EC2 instance
     :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default boto3 behaviour is used. If
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :param region_name: (optional) aws region name associated with the client
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
     :param check_interval: time in seconds that the job should wait in
         between each instance state checks until operation is completed
     """
 
+    aws_hook_class = EC2Hook
     operator_extra_links = (EC2InstanceLink(),)
-    template_fields: Sequence[str] = ("instance_id", "region_name")
+    template_fields: Sequence[str] = aws_template_fields("instance_id", "region_name")
     ui_color = "#eeaa11"
     ui_fgcolor = "#ffffff"
 
@@ -118,38 +120,33 @@ class EC2StopInstanceOperator(BaseOperator):
         self,
         *,
         instance_id: str,
-        aws_conn_id: str | None = "aws_default",
-        region_name: str | None = None,
         check_interval: float = 15,
         **kwargs,
     ):
         super().__init__(**kwargs)
         self.instance_id = instance_id
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.check_interval = check_interval
 
     def execute(self, context: Context):
-        ec2_hook = EC2Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
         self.log.info("Stopping EC2 instance %s", self.instance_id)
-        instance = ec2_hook.get_instance(instance_id=self.instance_id)
+        instance = self.hook.get_instance(instance_id=self.instance_id)
         EC2InstanceLink.persist(
             context=context,
             operator=self,
-            aws_partition=ec2_hook.conn_partition,
+            aws_partition=self.hook.conn_partition,
             instance_id=self.instance_id,
-            region_name=ec2_hook.conn_region_name,
+            region_name=self.hook.conn_region_name,
         )
         instance.stop()
 
-        ec2_hook.wait_for_state(
+        self.hook.wait_for_state(
             instance_id=self.instance_id,
             target_state="stopped",
             check_interval=self.check_interval,
         )
 
 
-class EC2CreateInstanceOperator(BaseOperator):
+class EC2CreateInstanceOperator(AwsBaseOperator[EC2Hook]):
     """
     Create and start a specified number of EC2 Instances using boto3.
 
@@ -161,11 +158,13 @@ class EC2CreateInstanceOperator(BaseOperator):
     :param max_count: Maximum number of instances to launch. Defaults to 1.
     :param min_count: Minimum number of instances to launch. Defaults to 1.
     :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default boto3 behaviour is used. If
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :param region_name: AWS region name associated with the client.
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
     :param poll_interval: Number of seconds to wait before attempting to
         check state of instance. Only used if wait_for_completion is True. Default is 20.
     :param max_attempts: Maximum number of attempts when checking state of instance.
@@ -175,8 +174,10 @@ class EC2CreateInstanceOperator(BaseOperator):
         in the `running` state before returning.
     """
 
+    aws_hook_class = EC2Hook
+
     operator_extra_links = (EC2InstanceDashboardLink(),)
-    template_fields: Sequence[str] = (
+    template_fields: Sequence[str] = aws_template_fields(
         "image_id",
         "max_count",
         "min_count",
@@ -191,8 +192,6 @@ class EC2CreateInstanceOperator(BaseOperator):
         image_id: str,
         max_count: int = 1,
         min_count: int = 1,
-        aws_conn_id: str | None = "aws_default",
-        region_name: str | None = None,
         poll_interval: int = 20,
         max_attempts: int = 20,
         config: dict | None = None,
@@ -203,62 +202,78 @@ class EC2CreateInstanceOperator(BaseOperator):
         self.image_id = image_id
         self.max_count = max_count
         self.min_count = min_count
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.poll_interval = poll_interval
         self.max_attempts = max_attempts
         self.config = config or {}
         self.wait_for_completion = wait_for_completion
 
+    @property
+    def _hook_parameters(self) -> dict[str, Any]:
+        return {**super()._hook_parameters, "api_type": "client_type"}
+
     def execute(self, context: Context):
-        ec2_hook = EC2Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name, api_type="client_type")
-        instances = ec2_hook.conn.run_instances(
+        instances = self.hook.conn.run_instances(
             ImageId=self.image_id,
             MinCount=self.min_count,
             MaxCount=self.max_count,
             **self.config,
         )["Instances"]
+        try:
+            instance_ids = self._on_kill_instance_ids = [instance["InstanceId"] for instance in instances]
+            # Console link is for EC2 dashboard list, not individual instances when more than 1 instance
 
-        instance_ids = self._on_kill_instance_ids = [instance["InstanceId"] for instance in instances]
-        # Console link is for EC2 dashboard list, not individual instances when more than 1 instance
+            EC2InstanceDashboardLink.persist(
+                context=context,
+                operator=self,
+                region_name=self.hook.conn_region_name,
+                aws_partition=self.hook.conn_partition,
+                instance_ids=EC2InstanceDashboardLink.format_instance_id_filter(instance_ids),
+            )
+            for instance_id in instance_ids:
+                self.log.info("Created EC2 instance %s", instance_id)
 
-        EC2InstanceDashboardLink.persist(
-            context=context,
-            operator=self,
-            region_name=ec2_hook.conn_region_name,
-            aws_partition=ec2_hook.conn_partition,
-            instance_ids=EC2InstanceDashboardLink.format_instance_id_filter(instance_ids),
-        )
-        for instance_id in instance_ids:
-            self.log.info("Created EC2 instance %s", instance_id)
+                if self.wait_for_completion:
+                    self.hook.get_waiter("instance_running").wait(
+                        InstanceIds=[instance_id],
+                        WaiterConfig={
+                            "Delay": self.poll_interval,
+                            "MaxAttempts": self.max_attempts,
+                        },
+                    )
 
-            if self.wait_for_completion:
-                ec2_hook.get_waiter("instance_running").wait(
-                    InstanceIds=[instance_id],
-                    WaiterConfig={
-                        "Delay": self.poll_interval,
-                        "MaxAttempts": self.max_attempts,
-                    },
+            # leave "_on_kill_instance_ids" in place for finishing post-processing
+            return instance_ids
+
+        # Best-effort cleanup when post-creation steps fail (e.g. IAM/permission errors).
+        except Exception:
+            self.log.exception(
+                "Exception after EC2 instance creation; attempting cleanup for instances %s",
+                instance_ids,
+            )
+            try:
+                self.hook.terminate_instances(instance_ids=instance_ids)
+            except Exception:
+                self.log.exception(
+                    "Failed to cleanup EC2 instances %s after task failure",
+                    instance_ids,
                 )
-
-        # leave "_on_kill_instance_ids" in place for finishing post-processing
-        return instance_ids
+            raise
 
     def on_kill(self) -> None:
         instance_ids = getattr(self, "_on_kill_instance_ids", [])
 
         if instance_ids:
             self.log.info("on_kill: Terminating instance/s %s", ", ".join(instance_ids))
-            ec2_hook = EC2Hook(
+            """ ec2_hook = EC2Hook(
                 aws_conn_id=self.aws_conn_id,
                 region_name=self.region_name,
                 api_type="client_type",
-            )
-            ec2_hook.conn.terminate_instances(InstanceIds=instance_ids)
+            ) """
+            self.hook.terminate_instances(instance_ids=instance_ids)
         super().on_kill()
 
 
-class EC2TerminateInstanceOperator(BaseOperator):
+class EC2TerminateInstanceOperator(AwsBaseOperator[EC2Hook]):
     """
     Terminate EC2 Instances using boto3.
 
@@ -268,11 +283,13 @@ class EC2TerminateInstanceOperator(BaseOperator):
 
     :param instance_id: ID of the instance to be terminated.
     :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default boto3 behaviour is used. If
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :param region_name: AWS region name associated with the client.
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
     :param poll_interval: Number of seconds to wait before attempting to
         check state of instance. Only used if wait_for_completion is True. Default is 20.
     :param max_attempts: Maximum number of attempts when checking state of instance.
@@ -281,13 +298,14 @@ class EC2TerminateInstanceOperator(BaseOperator):
         in the `terminated` state before returning.
     """
 
-    template_fields: Sequence[str] = ("instance_ids", "region_name", "aws_conn_id", "wait_for_completion")
+    aws_hook_class = EC2Hook
+    template_fields: Sequence[str] = aws_template_fields(
+        "instance_ids", "region_name", "aws_conn_id", "wait_for_completion"
+    )
 
     def __init__(
         self,
         instance_ids: str | list[str],
-        aws_conn_id: str | None = "aws_default",
-        region_name: str | None = None,
         poll_interval: int = 20,
         max_attempts: int = 20,
         wait_for_completion: bool = False,
@@ -295,22 +313,23 @@ class EC2TerminateInstanceOperator(BaseOperator):
     ):
         super().__init__(**kwargs)
         self.instance_ids = instance_ids
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.poll_interval = poll_interval
         self.max_attempts = max_attempts
         self.wait_for_completion = wait_for_completion
 
+    @property
+    def _hook_parameters(self) -> dict[str, Any]:
+        return {**super()._hook_parameters, "api_type": "client_type"}
+
     def execute(self, context: Context):
         if isinstance(self.instance_ids, str):
             self.instance_ids = [self.instance_ids]
-        ec2_hook = EC2Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name, api_type="client_type")
-        ec2_hook.conn.terminate_instances(InstanceIds=self.instance_ids)
+        self.hook.conn.terminate_instances(InstanceIds=self.instance_ids)
 
         for instance_id in self.instance_ids:
             self.log.info("Terminating EC2 instance %s", instance_id)
             if self.wait_for_completion:
-                ec2_hook.get_waiter("instance_terminated").wait(
+                self.hook.get_waiter("instance_terminated").wait(
                     InstanceIds=[instance_id],
                     WaiterConfig={
                         "Delay": self.poll_interval,
@@ -319,7 +338,7 @@ class EC2TerminateInstanceOperator(BaseOperator):
                 )
 
 
-class EC2RebootInstanceOperator(BaseOperator):
+class EC2RebootInstanceOperator(AwsBaseOperator[EC2Hook]):
     """
     Reboot Amazon EC2 instances.
 
@@ -329,11 +348,13 @@ class EC2RebootInstanceOperator(BaseOperator):
 
     :param instance_ids: ID of the instance(s) to be rebooted.
     :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default boto3 behaviour is used. If
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :param region_name: AWS region name associated with the client.
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
     :param poll_interval: Number of seconds to wait before attempting to
         check state of instance. Only used if wait_for_completion is True. Default is 20.
     :param max_attempts: Maximum number of attempts when checking state of instance.
@@ -342,8 +363,9 @@ class EC2RebootInstanceOperator(BaseOperator):
         in the `running` state before returning.
     """
 
+    aws_hook_class = EC2Hook
     operator_extra_links = (EC2InstanceDashboardLink(),)
-    template_fields: Sequence[str] = ("instance_ids", "region_name")
+    template_fields: Sequence[str] = aws_template_fields("instance_ids", "region_name")
     ui_color = "#eeaa11"
     ui_fgcolor = "#ffffff"
 
@@ -351,8 +373,6 @@ class EC2RebootInstanceOperator(BaseOperator):
         self,
         *,
         instance_ids: str | list[str],
-        aws_conn_id: str | None = "aws_default",
-        region_name: str | None = None,
         poll_interval: int = 20,
         max_attempts: int = 20,
         wait_for_completion: bool = False,
@@ -360,29 +380,30 @@ class EC2RebootInstanceOperator(BaseOperator):
     ):
         super().__init__(**kwargs)
         self.instance_ids = instance_ids
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.poll_interval = poll_interval
         self.max_attempts = max_attempts
         self.wait_for_completion = wait_for_completion
 
+    @property
+    def _hook_parameters(self) -> dict[str, Any]:
+        return {**super()._hook_parameters, "api_type": "client_type"}
+
     def execute(self, context: Context):
         if isinstance(self.instance_ids, str):
             self.instance_ids = [self.instance_ids]
-        ec2_hook = EC2Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name, api_type="client_type")
         self.log.info("Rebooting EC2 instances %s", ", ".join(self.instance_ids))
-        ec2_hook.conn.reboot_instances(InstanceIds=self.instance_ids)
+        self.hook.conn.reboot_instances(InstanceIds=self.instance_ids)
 
         # Console link is for EC2 dashboard list, not individual instances
         EC2InstanceDashboardLink.persist(
             context=context,
             operator=self,
-            region_name=ec2_hook.conn_region_name,
-            aws_partition=ec2_hook.conn_partition,
+            region_name=self.hook.conn_region_name,
+            aws_partition=self.hook.conn_partition,
             instance_ids=EC2InstanceDashboardLink.format_instance_id_filter(self.instance_ids),
         )
         if self.wait_for_completion:
-            ec2_hook.get_waiter("instance_running").wait(
+            self.hook.get_waiter("instance_running").wait(
                 InstanceIds=self.instance_ids,
                 WaiterConfig={
                     "Delay": self.poll_interval,
@@ -391,7 +412,7 @@ class EC2RebootInstanceOperator(BaseOperator):
             )
 
 
-class EC2HibernateInstanceOperator(BaseOperator):
+class EC2HibernateInstanceOperator(AwsBaseOperator[EC2Hook]):
     """
     Hibernate Amazon EC2 instances.
 
@@ -401,11 +422,13 @@ class EC2HibernateInstanceOperator(BaseOperator):
 
     :param instance_ids: ID of the instance(s) to be hibernated.
     :param aws_conn_id: The Airflow connection used for AWS credentials.
-        If this is None or empty then the default boto3 behaviour is used. If
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :param region_name: AWS region name associated with the client.
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
     :param poll_interval: Number of seconds to wait before attempting to
         check state of instance. Only used if wait_for_completion is True. Default is 20.
     :param max_attempts: Maximum number of attempts when checking state of instance.
@@ -414,8 +437,9 @@ class EC2HibernateInstanceOperator(BaseOperator):
         in the `stopped` state before returning.
     """
 
+    aws_hook_class = EC2Hook
     operator_extra_links = (EC2InstanceDashboardLink(),)
-    template_fields: Sequence[str] = ("instance_ids", "region_name")
+    template_fields: Sequence[str] = aws_template_fields("instance_ids", "region_name")
     ui_color = "#eeaa11"
     ui_fgcolor = "#ffffff"
 
@@ -423,8 +447,6 @@ class EC2HibernateInstanceOperator(BaseOperator):
         self,
         *,
         instance_ids: str | list[str],
-        aws_conn_id: str | None = "aws_default",
-        region_name: str | None = None,
         poll_interval: int = 20,
         max_attempts: int = 20,
         wait_for_completion: bool = False,
@@ -432,25 +454,26 @@ class EC2HibernateInstanceOperator(BaseOperator):
     ):
         super().__init__(**kwargs)
         self.instance_ids = instance_ids
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.poll_interval = poll_interval
         self.max_attempts = max_attempts
         self.wait_for_completion = wait_for_completion
 
+    @property
+    def _hook_parameters(self) -> dict[str, Any]:
+        return {**super()._hook_parameters, "api_type": "client_type"}
+
     def execute(self, context: Context):
         if isinstance(self.instance_ids, str):
             self.instance_ids = [self.instance_ids]
-        ec2_hook = EC2Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name, api_type="client_type")
         self.log.info("Hibernating EC2 instances %s", ", ".join(self.instance_ids))
-        instances = ec2_hook.get_instances(instance_ids=self.instance_ids)
+        instances = self.hook.get_instances(instance_ids=self.instance_ids)
 
         # Console link is for EC2 dashboard list, not individual instances
         EC2InstanceDashboardLink.persist(
             context=context,
             operator=self,
-            region_name=ec2_hook.conn_region_name,
-            aws_partition=ec2_hook.conn_partition,
+            region_name=self.hook.conn_region_name,
+            aws_partition=self.hook.conn_partition,
             instance_ids=EC2InstanceDashboardLink.format_instance_id_filter(self.instance_ids),
         )
 
@@ -459,10 +482,10 @@ class EC2HibernateInstanceOperator(BaseOperator):
             if not hibernation_options or not hibernation_options["Configured"]:
                 raise AirflowException(f"Instance {instance['InstanceId']} is not configured for hibernation")
 
-        ec2_hook.conn.stop_instances(InstanceIds=self.instance_ids, Hibernate=True)
+        self.hook.conn.stop_instances(InstanceIds=self.instance_ids, Hibernate=True)
 
         if self.wait_for_completion:
-            ec2_hook.get_waiter("instance_stopped").wait(
+            self.hook.get_waiter("instance_stopped").wait(
                 InstanceIds=self.instance_ids,
                 WaiterConfig={
                     "Delay": self.poll_interval,
