@@ -30,15 +30,12 @@ from airflow.providers.common.compat.sdk import AirflowException
 from airflow.utils.state import DagRunState
 from airflow.utils.types import DagRunType
 
+from tests_common.test_utils.compat import timezone
 from tests_common.test_utils.dag import sync_dag_to_db
+from tests_common.test_utils.taskinstance import create_task_instance, get_template_context
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 from unit.amazon.aws.utils.test_template_fields import validate_template_fields
 
-try:
-    from airflow.sdk import timezone
-except ImportError:
-    from airflow.utils import timezone  # type: ignore[attr-defined,no-redef]
-
 TEST_DAG_ID = "unit_tests"
 DEFAULT_DATE = timezone.datetime(2018, 1, 1)
 
@@ -372,7 +369,7 @@ class TestDataSyncOperatorCreate(DataSyncTestCaseBase):
                 run_type=DagRunType.MANUAL,
                 state=DagRunState.RUNNING,
             )
-            ti = TaskInstance(task=self.datasync, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=self.datasync, run_id="test", dag_version_id=dag_version.id)
         else:
             dag_run = DagRun(
                 dag_id=self.dag.dag_id,
@@ -385,7 +382,7 @@ class TestDataSyncOperatorCreate(DataSyncTestCaseBase):
         ti.dag_run = dag_run
         session.add(ti)
         session.commit()
-        assert self.datasync.execute(ti.get_template_context()) is not None
+        assert self.datasync.execute(get_template_context(ti, self.datasync)) is not None
         # ### Check mocks:
         mock_get_conn.assert_called()
 
@@ -586,7 +583,7 @@ class TestDataSyncOperatorGetTasks(DataSyncTestCaseBase):
 
             sync_dag_to_db(self.dag)
             dag_version = DagVersion.get_latest_version(self.dag.dag_id)
-            ti = TaskInstance(task=self.datasync, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=self.datasync, run_id="test", dag_version_id=dag_version.id)
             dag_run = DagRun(
                 dag_id=self.dag.dag_id,
                 logical_date=timezone.utcnow(),
@@ -606,7 +603,7 @@ class TestDataSyncOperatorGetTasks(DataSyncTestCaseBase):
         ti.dag_run = dag_run
         session.add(ti)
         session.commit()
-        result = self.datasync.execute(ti.get_template_context())
+        result = self.datasync.execute(get_template_context(ti, self.datasync))
         assert result["TaskArn"] == self.task_arn
         # ### Check mocks:
         mock_get_conn.assert_called()
@@ -709,7 +706,7 @@ class TestDataSyncOperatorUpdate(DataSyncTestCaseBase):
 
             sync_dag_to_db(self.dag)
             dag_version = DagVersion.get_latest_version(self.dag.dag_id)
-            ti = TaskInstance(task=self.datasync, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=self.datasync, run_id="test", dag_version_id=dag_version.id)
             dag_run = DagRun(
                 dag_id=self.dag.dag_id,
                 logical_date=timezone.utcnow(),
@@ -729,7 +726,7 @@ class TestDataSyncOperatorUpdate(DataSyncTestCaseBase):
         ti.dag_run = dag_run
         session.add(ti)
         session.commit()
-        result = self.datasync.execute(ti.get_template_context())
+        result = self.datasync.execute(get_template_context(ti, self.datasync))
         assert result["TaskArn"] == self.task_arn
         # ### Check mocks:
         mock_get_conn.assert_called()
@@ -925,7 +922,7 @@ class TestDataSyncOperator(DataSyncTestCaseBase):
 
             sync_dag_to_db(self.dag)
             dag_version = DagVersion.get_latest_version(self.dag.dag_id)
-            ti = TaskInstance(task=self.datasync, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=self.datasync, run_id="test", dag_version_id=dag_version.id)
             dag_run = DagRun(
                 dag_id=self.dag.dag_id,
                 logical_date=timezone.utcnow(),
@@ -945,7 +942,7 @@ class TestDataSyncOperator(DataSyncTestCaseBase):
         ti.dag_run = dag_run
         session.add(ti)
         session.commit()
-        assert self.datasync.execute(ti.get_template_context()) is not None
+        assert self.datasync.execute(get_template_context(ti, self.datasync)) is not None
         # ### Check mocks:
         mock_get_conn.assert_called()
 
@@ -1044,7 +1041,7 @@ class TestDataSyncOperatorDelete(DataSyncTestCaseBase):
 
             sync_dag_to_db(self.dag)
             dag_version = DagVersion.get_latest_version(self.dag.dag_id)
-            ti = TaskInstance(task=self.datasync, dag_version_id=dag_version.id)
+            ti = create_task_instance(task=self.datasync, run_id="test", dag_version_id=dag_version.id)
             dag_run = DagRun(
                 dag_id=self.dag.dag_id,
                 logical_date=timezone.utcnow(),
@@ -1064,7 +1061,7 @@ class TestDataSyncOperatorDelete(DataSyncTestCaseBase):
         ti.dag_run = dag_run
         session.add(ti)
         session.commit()
-        result = self.datasync.execute(ti.get_template_context())
+        result = self.datasync.execute(get_template_context(ti, self.datasync))
         assert result["TaskArn"] == self.task_arn
         # ### Check mocks:
         mock_get_conn.assert_called()
